/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.discovery.model;

import com.google.api.client.json.GenericJson;

/**
 * Model definition for JsonSchema.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the APIs Discovery Service. For a detailed explanation
 * see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class JsonSchema extends GenericJson {

  /**
   * A reference to another schema. The value of this property is the "id" of another schema.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String $ref;

  /**
   * If this is a schema for an object, this property is the schema for any additional properties
   * with dynamic keys on this object.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private JsonSchema additionalProperties;

  /**
   * Additional information about this property.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Annotations annotations;

  /**
   * The default value of this property (if one exists).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key("default")
  private String discoveryDefault;

  /**
   * A description of this object.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String description;

  /**
   * Values this parameter may take (if it is an enum).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key("enum")
  private java.util.List<String> discoveryEnum;

  /**
   * The descriptions for the enums. Each position maps to the corresponding value in the "enum"
   * array.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> enumDescriptions;

  /**
   * An additional regular expression or key that helps constrain the value. For more details see:
   * http://tools.ietf.org/html/draft-zyp-json-schema-03#section-5.23
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String format;

  /**
   * Unique identifier for this schema.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * If this is a schema for an array, this property is the schema for each element in the array.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private JsonSchema items;

  /**
   * Whether this parameter goes in the query or the path for REST requests.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String location;

  /**
   * The maximum value of this parameter.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String maximum;

  /**
   * The minimum value of this parameter.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String minimum;

  /**
   * The regular expression this parameter must conform to. Uses Java 6 regex format:
   * http://docs.oracle.com/javase/6/docs/api/java/util/regex/Pattern.html
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String pattern;

  /**
   * If this is a schema for an object, list the schema for each property of this object.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.Map<String, JsonSchema> properties;

  static {
    // hack to force ProGuard to consider JsonSchema used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(JsonSchema.class);
  }

  /**
   * The value is read-only, generated by the service. The value can not be modified by the client.
   * It the value is included in a POST, PUT or PATCH request, it will be ignored by the service.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean readOnly;

  /**
   * Whether this parameter may appear multiple times.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean repeated;

  /**
   * Whether the parameter is required.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean required;

  /**
   * The value type for this schema. A list of values can be found here: http://tools.ietf.org/html
   * /draft-zyp-json-schema-03#section-5.1
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String type;

  /**
   * A reference to another schema. The value of this property is the "id" of another schema.
   * The value returned may be {@code null}.
   */
  public String get$ref() {
    return $ref;
  }

  /**
   * A reference to another schema. The value of this property is the "id" of another schema.
   * The value set may be {@code null}.
   */
  public JsonSchema set$ref(String $ref) {
    this.$ref = $ref;
    return this;
  }

  /**
   * If this is a schema for an object, this property is the schema for any additional properties
   * with dynamic keys on this object.
   * The value returned may be {@code null}.
   */
  public JsonSchema getAdditionalProperties() {
    return additionalProperties;
  }

  /**
   * If this is a schema for an object, this property is the schema for any additional properties
   * with dynamic keys on this object.
   * The value set may be {@code null}.
   */
  public JsonSchema setAdditionalProperties(JsonSchema additionalProperties) {
    this.additionalProperties = additionalProperties;
    return this;
  }

  /**
   * Additional information about this property.
   * The value returned may be {@code null}.
   */
  public Annotations getAnnotations() {
    return annotations;
  }

  /**
   * Additional information about this property.
   * The value set may be {@code null}.
   */
  public JsonSchema setAnnotations(Annotations annotations) {
    this.annotations = annotations;
    return this;
  }

  /**
   * The default value of this property (if one exists).
   * The value returned may be {@code null}.
   */
  public String getDefault() {
    return discoveryDefault;
  }

  /**
   * The default value of this property (if one exists).
   * The value set may be {@code null}.
   */
  public JsonSchema setDefault(String discoveryDefault) {
    this.discoveryDefault = discoveryDefault;
    return this;
  }

  /**
   * A description of this object.
   * The value returned may be {@code null}.
   */
  public String getDescription() {
    return description;
  }

  /**
   * A description of this object.
   * The value set may be {@code null}.
   */
  public JsonSchema setDescription(String description) {
    this.description = description;
    return this;
  }

  /**
   * Values this parameter may take (if it is an enum).
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getEnum() {
    return discoveryEnum;
  }

  /**
   * Values this parameter may take (if it is an enum).
   * The value set may be {@code null}.
   */
  public JsonSchema setEnum(java.util.List<String> discoveryEnum) {
    this.discoveryEnum = discoveryEnum;
    return this;
  }

  /**
   * The descriptions for the enums. Each position maps to the corresponding value in the "enum"
   * array.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getEnumDescriptions() {
    return enumDescriptions;
  }

  /**
   * The descriptions for the enums. Each position maps to the corresponding value in the "enum"
   * array.
   * The value set may be {@code null}.
   */
  public JsonSchema setEnumDescriptions(java.util.List<String> enumDescriptions) {
    this.enumDescriptions = enumDescriptions;
    return this;
  }

  /**
   * An additional regular expression or key that helps constrain the value. For more details see:
   * http://tools.ietf.org/html/draft-zyp-json-schema-03#section-5.23
   * The value returned may be {@code null}.
   */
  public String getFormat() {
    return format;
  }

  /**
   * An additional regular expression or key that helps constrain the value. For more details see:
   * http://tools.ietf.org/html/draft-zyp-json-schema-03#section-5.23
   * The value set may be {@code null}.
   */
  public JsonSchema setFormat(String format) {
    this.format = format;
    return this;
  }

  /**
   * Unique identifier for this schema.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * Unique identifier for this schema.
   * The value set may be {@code null}.
   */
  public JsonSchema setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * If this is a schema for an array, this property is the schema for each element in the array.
   * The value returned may be {@code null}.
   */
  public JsonSchema getItems() {
    return items;
  }

  /**
   * If this is a schema for an array, this property is the schema for each element in the array.
   * The value set may be {@code null}.
   */
  public JsonSchema setItems(JsonSchema items) {
    this.items = items;
    return this;
  }

  /**
   * Whether this parameter goes in the query or the path for REST requests.
   * The value returned may be {@code null}.
   */
  public String getLocation() {
    return location;
  }

  /**
   * Whether this parameter goes in the query or the path for REST requests.
   * The value set may be {@code null}.
   */
  public JsonSchema setLocation(String location) {
    this.location = location;
    return this;
  }

  /**
   * The maximum value of this parameter.
   * The value returned may be {@code null}.
   */
  public String getMaximum() {
    return maximum;
  }

  /**
   * The maximum value of this parameter.
   * The value set may be {@code null}.
   */
  public JsonSchema setMaximum(String maximum) {
    this.maximum = maximum;
    return this;
  }

  /**
   * The minimum value of this parameter.
   * The value returned may be {@code null}.
   */
  public String getMinimum() {
    return minimum;
  }

  /**
   * The minimum value of this parameter.
   * The value set may be {@code null}.
   */
  public JsonSchema setMinimum(String minimum) {
    this.minimum = minimum;
    return this;
  }

  /**
   * The regular expression this parameter must conform to. Uses Java 6 regex format:
   * http://docs.oracle.com/javase/6/docs/api/java/util/regex/Pattern.html
   * The value returned may be {@code null}.
   */
  public String getPattern() {
    return pattern;
  }

  /**
   * The regular expression this parameter must conform to. Uses Java 6 regex format:
   * http://docs.oracle.com/javase/6/docs/api/java/util/regex/Pattern.html
   * The value set may be {@code null}.
   */
  public JsonSchema setPattern(String pattern) {
    this.pattern = pattern;
    return this;
  }

  /**
   * If this is a schema for an object, list the schema for each property of this object.
   * The value returned may be {@code null}.
   */
  public java.util.Map<String, JsonSchema> getProperties() {
    return properties;
  }

  /**
   * If this is a schema for an object, list the schema for each property of this object.
   * The value set may be {@code null}.
   */
  public JsonSchema setProperties(java.util.Map<String, JsonSchema> properties) {
    this.properties = properties;
    return this;
  }

  /**
   * The value is read-only, generated by the service. The value can not be modified by the client.
   * It the value is included in a POST, PUT or PATCH request, it will be ignored by the service.
   * The value returned may be {@code null}.
   */
  public Boolean getReadOnly() {
    return readOnly;
  }

  /**
   * The value is read-only, generated by the service. The value can not be modified by the client.
   * It the value is included in a POST, PUT or PATCH request, it will be ignored by the service.
   * The value set may be {@code null}.
   */
  public JsonSchema setReadOnly(Boolean readOnly) {
    this.readOnly = readOnly;
    return this;
  }

  /**
   * Whether this parameter may appear multiple times.
   * The value returned may be {@code null}.
   */
  public Boolean getRepeated() {
    return repeated;
  }

  /**
   * Whether this parameter may appear multiple times.
   * The value set may be {@code null}.
   */
  public JsonSchema setRepeated(Boolean repeated) {
    this.repeated = repeated;
    return this;
  }

  /**
   * Whether the parameter is required.
   * The value returned may be {@code null}.
   */
  public Boolean getRequired() {
    return required;
  }

  /**
   * Whether the parameter is required.
   * The value set may be {@code null}.
   */
  public JsonSchema setRequired(Boolean required) {
    this.required = required;
    return this;
  }

  /**
   * The value type for this schema. A list of values can be found here: http://tools.ietf.org/html
   * /draft-zyp-json-schema-03#section-5.1
   * The value returned may be {@code null}.
   */
  public String getType() {
    return type;
  }

  /**
   * The value type for this schema. A list of values can be found here: http://tools.ietf.org/html
   * /draft-zyp-json-schema-03#section-5.1
   * The value set may be {@code null}.
   */
  public JsonSchema setType(String type) {
    this.type = type;
    return this;
  }

  /**
   * Additional information about this property.
   */
  public static final class Annotations extends GenericJson {

    /**
     * A list of methods for which this property is required on requests.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private java.util.List<String> required;

    /**
     * A list of methods for which this property is required on requests.
     * The value returned may be {@code null}.
     */
    public java.util.List<String> getRequired() {
      return required;
    }

    /**
     * A list of methods for which this property is required on requests.
     * The value set may be {@code null}.
     */
    public Annotations setRequired(java.util.List<String> required) {
      this.required = required;
      return this;
    }

  }

}
