/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.discovery.model;

import com.google.api.client.json.GenericJson;

/**
 * Model definition for RestDescription.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the APIs Discovery Service. For a detailed explanation
 * see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class RestDescription extends GenericJson {

  /**
   * Authentication information.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Auth auth;

  /**
   * [DEPRECATED] The base path for REST requests.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String basePath;

  /**
   * [DEPRECATED] The base URL for REST requests.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String baseUrl;

  /**
   * The path for REST batch requests.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String batchPath;

  /**
   * Indicates how the API name should be capitalized and split into various parts. Useful for
   * generating pretty class names.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String canonicalName;

  /**
   * The description of this API.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String description;

  /**
   * Indicate the version of the Discovery API used to generate this doc.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String discoveryVersion;

  /**
   * A link to human readable documentation for the API.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String documentationLink;

  /**
   * The etag for this response.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String etag;

  /**
   * A list of supported features for this API.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> features;

  /**
   * Links to 16x16 and 32x32 icons representing the API.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Icons icons;

  /**
   * The id of this API.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * The kind for this response.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * Labels for the status of this API, such as labs or deprecated.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> labels;

  /**
   * API-level methods for this API.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.Map<String, RestMethod> methods;

  static {
    // hack to force ProGuard to consider RestMethod used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(RestMethod.class);
  }

  /**
   * The name of this API.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String name;

  /**
   * Common parameters that apply across all apis.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.Map<String, JsonSchema> parameters;

  static {
    // hack to force ProGuard to consider JsonSchema used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(JsonSchema.class);
  }

  /**
   * The protocol described by this document.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String protocol;

  /**
   * The resources in this API.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.Map<String, RestResource> resources;

  static {
    // hack to force ProGuard to consider RestResource used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(RestResource.class);
  }

  /**
   * The version of this API.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String revision;

  /**
   * The root url under which all API services live.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String rootUrl;

  /**
   * The schemas for this API.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.Map<String, JsonSchema> schemas;

  static {
    // hack to force ProGuard to consider JsonSchema used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(JsonSchema.class);
  }

  /**
   * The base path for all REST requests.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String servicePath;

  /**
   * The title of this API.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String title;

  /**
   * The version of this API.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String version;

  /**
   * Authentication information.
   * The value returned may be {@code null}.
   */
  public Auth getAuth() {
    return auth;
  }

  /**
   * Authentication information.
   * The value set may be {@code null}.
   */
  public RestDescription setAuth(Auth auth) {
    this.auth = auth;
    return this;
  }

  /**
   * [DEPRECATED] The base path for REST requests.
   * The value returned may be {@code null}.
   */
  public String getBasePath() {
    return basePath;
  }

  /**
   * [DEPRECATED] The base path for REST requests.
   * The value set may be {@code null}.
   */
  public RestDescription setBasePath(String basePath) {
    this.basePath = basePath;
    return this;
  }

  /**
   * [DEPRECATED] The base URL for REST requests.
   * The value returned may be {@code null}.
   */
  public String getBaseUrl() {
    return baseUrl;
  }

  /**
   * [DEPRECATED] The base URL for REST requests.
   * The value set may be {@code null}.
   */
  public RestDescription setBaseUrl(String baseUrl) {
    this.baseUrl = baseUrl;
    return this;
  }

  /**
   * The path for REST batch requests.
   * The value returned may be {@code null}.
   */
  public String getBatchPath() {
    return batchPath;
  }

  /**
   * The path for REST batch requests.
   * The value set may be {@code null}.
   */
  public RestDescription setBatchPath(String batchPath) {
    this.batchPath = batchPath;
    return this;
  }

  /**
   * Indicates how the API name should be capitalized and split into various parts. Useful for
   * generating pretty class names.
   * The value returned may be {@code null}.
   */
  public String getCanonicalName() {
    return canonicalName;
  }

  /**
   * Indicates how the API name should be capitalized and split into various parts. Useful for
   * generating pretty class names.
   * The value set may be {@code null}.
   */
  public RestDescription setCanonicalName(String canonicalName) {
    this.canonicalName = canonicalName;
    return this;
  }

  /**
   * The description of this API.
   * The value returned may be {@code null}.
   */
  public String getDescription() {
    return description;
  }

  /**
   * The description of this API.
   * The value set may be {@code null}.
   */
  public RestDescription setDescription(String description) {
    this.description = description;
    return this;
  }

  /**
   * Indicate the version of the Discovery API used to generate this doc.
   * The value returned may be {@code null}.
   */
  public String getDiscoveryVersion() {
    return discoveryVersion;
  }

  /**
   * Indicate the version of the Discovery API used to generate this doc.
   * The value set may be {@code null}.
   */
  public RestDescription setDiscoveryVersion(String discoveryVersion) {
    this.discoveryVersion = discoveryVersion;
    return this;
  }

  /**
   * A link to human readable documentation for the API.
   * The value returned may be {@code null}.
   */
  public String getDocumentationLink() {
    return documentationLink;
  }

  /**
   * A link to human readable documentation for the API.
   * The value set may be {@code null}.
   */
  public RestDescription setDocumentationLink(String documentationLink) {
    this.documentationLink = documentationLink;
    return this;
  }

  /**
   * The etag for this response.
   * The value returned may be {@code null}.
   */
  public String getEtag() {
    return etag;
  }

  /**
   * The etag for this response.
   * The value set may be {@code null}.
   */
  public RestDescription setEtag(String etag) {
    this.etag = etag;
    return this;
  }

  /**
   * A list of supported features for this API.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getFeatures() {
    return features;
  }

  /**
   * A list of supported features for this API.
   * The value set may be {@code null}.
   */
  public RestDescription setFeatures(java.util.List<String> features) {
    this.features = features;
    return this;
  }

  /**
   * Links to 16x16 and 32x32 icons representing the API.
   * The value returned may be {@code null}.
   */
  public Icons getIcons() {
    return icons;
  }

  /**
   * Links to 16x16 and 32x32 icons representing the API.
   * The value set may be {@code null}.
   */
  public RestDescription setIcons(Icons icons) {
    this.icons = icons;
    return this;
  }

  /**
   * The id of this API.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * The id of this API.
   * The value set may be {@code null}.
   */
  public RestDescription setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * The kind for this response.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind for this response.
   * The value set may be {@code null}.
   */
  public RestDescription setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * Labels for the status of this API, such as labs or deprecated.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getLabels() {
    return labels;
  }

  /**
   * Labels for the status of this API, such as labs or deprecated.
   * The value set may be {@code null}.
   */
  public RestDescription setLabels(java.util.List<String> labels) {
    this.labels = labels;
    return this;
  }

  /**
   * API-level methods for this API.
   * The value returned may be {@code null}.
   */
  public java.util.Map<String, RestMethod> getMethods() {
    return methods;
  }

  /**
   * API-level methods for this API.
   * The value set may be {@code null}.
   */
  public RestDescription setMethods(java.util.Map<String, RestMethod> methods) {
    this.methods = methods;
    return this;
  }

  /**
   * The name of this API.
   * The value returned may be {@code null}.
   */
  public String getName() {
    return name;
  }

  /**
   * The name of this API.
   * The value set may be {@code null}.
   */
  public RestDescription setName(String name) {
    this.name = name;
    return this;
  }

  /**
   * Common parameters that apply across all apis.
   * The value returned may be {@code null}.
   */
  public java.util.Map<String, JsonSchema> getParameters() {
    return parameters;
  }

  /**
   * Common parameters that apply across all apis.
   * The value set may be {@code null}.
   */
  public RestDescription setParameters(java.util.Map<String, JsonSchema> parameters) {
    this.parameters = parameters;
    return this;
  }

  /**
   * The protocol described by this document.
   * The value returned may be {@code null}.
   */
  public String getProtocol() {
    return protocol;
  }

  /**
   * The protocol described by this document.
   * The value set may be {@code null}.
   */
  public RestDescription setProtocol(String protocol) {
    this.protocol = protocol;
    return this;
  }

  /**
   * The resources in this API.
   * The value returned may be {@code null}.
   */
  public java.util.Map<String, RestResource> getResources() {
    return resources;
  }

  /**
   * The resources in this API.
   * The value set may be {@code null}.
   */
  public RestDescription setResources(java.util.Map<String, RestResource> resources) {
    this.resources = resources;
    return this;
  }

  /**
   * The version of this API.
   * The value returned may be {@code null}.
   */
  public String getRevision() {
    return revision;
  }

  /**
   * The version of this API.
   * The value set may be {@code null}.
   */
  public RestDescription setRevision(String revision) {
    this.revision = revision;
    return this;
  }

  /**
   * The root url under which all API services live.
   * The value returned may be {@code null}.
   */
  public String getRootUrl() {
    return rootUrl;
  }

  /**
   * The root url under which all API services live.
   * The value set may be {@code null}.
   */
  public RestDescription setRootUrl(String rootUrl) {
    this.rootUrl = rootUrl;
    return this;
  }

  /**
   * The schemas for this API.
   * The value returned may be {@code null}.
   */
  public java.util.Map<String, JsonSchema> getSchemas() {
    return schemas;
  }

  /**
   * The schemas for this API.
   * The value set may be {@code null}.
   */
  public RestDescription setSchemas(java.util.Map<String, JsonSchema> schemas) {
    this.schemas = schemas;
    return this;
  }

  /**
   * The base path for all REST requests.
   * The value returned may be {@code null}.
   */
  public String getServicePath() {
    return servicePath;
  }

  /**
   * The base path for all REST requests.
   * The value set may be {@code null}.
   */
  public RestDescription setServicePath(String servicePath) {
    this.servicePath = servicePath;
    return this;
  }

  /**
   * The title of this API.
   * The value returned may be {@code null}.
   */
  public String getTitle() {
    return title;
  }

  /**
   * The title of this API.
   * The value set may be {@code null}.
   */
  public RestDescription setTitle(String title) {
    this.title = title;
    return this;
  }

  /**
   * The version of this API.
   * The value returned may be {@code null}.
   */
  public String getVersion() {
    return version;
  }

  /**
   * The version of this API.
   * The value set may be {@code null}.
   */
  public RestDescription setVersion(String version) {
    this.version = version;
    return this;
  }

  /**
   * Authentication information.
   */
  public static final class Auth extends GenericJson {

    /**
     * OAuth 2.0 authentication information.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Oauth2 oauth2;

    /**
     * OAuth 2.0 authentication information.
     * The value returned may be {@code null}.
     */
    public Oauth2 getOauth2() {
      return oauth2;
    }

    /**
     * OAuth 2.0 authentication information.
     * The value set may be {@code null}.
     */
    public Auth setOauth2(Oauth2 oauth2) {
      this.oauth2 = oauth2;
      return this;
    }

    /**
     * OAuth 2.0 authentication information.
     */
    public static final class Oauth2 extends GenericJson {

      /**
       * Available OAuth 2.0 scopes.
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private java.util.Map<String, Scopes> scopes;

      static {
        // hack to force ProGuard to consider Scopes used, since otherwise it would be stripped out
        // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
        com.google.api.client.util.Data.nullOf(Scopes.class);
      }

      /**
       * Available OAuth 2.0 scopes.
       * The value returned may be {@code null}.
       */
      public java.util.Map<String, Scopes> getScopes() {
        return scopes;
      }

      /**
       * Available OAuth 2.0 scopes.
       * The value set may be {@code null}.
       */
      public Oauth2 setScopes(java.util.Map<String, Scopes> scopes) {
        this.scopes = scopes;
        return this;
      }

      /**
       * The scope value.
       */
      public static final class Scopes extends GenericJson {

        /**
         * Description of scope.
         * The value may be {@code null}.
         */
        @com.google.api.client.util.Key
        private String description;

        /**
         * Description of scope.
         * The value returned may be {@code null}.
         */
        public String getDescription() {
          return description;
        }

        /**
         * Description of scope.
         * The value set may be {@code null}.
         */
        public Scopes setDescription(String description) {
          this.description = description;
          return this;
        }

      }
    }
  }

  /**
   * Links to 16x16 and 32x32 icons representing the API.
   */
  public static final class Icons extends GenericJson {

    /**
     * The url of the 16x16 icon.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String x16;

    /**
     * The url of the 32x32 icon.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String x32;

    /**
     * The url of the 16x16 icon.
     * The value returned may be {@code null}.
     */
    public String getX16() {
      return x16;
    }

    /**
     * The url of the 16x16 icon.
     * The value set may be {@code null}.
     */
    public Icons setX16(String x16) {
      this.x16 = x16;
      return this;
    }

    /**
     * The url of the 32x32 icon.
     * The value returned may be {@code null}.
     */
    public String getX32() {
      return x32;
    }

    /**
     * The url of the 32x32 icon.
     * The value set may be {@code null}.
     */
    public Icons setX32(String x32) {
      this.x32 = x32;
      return this;
    }

  }

}
